/**
 * \defgroup 20_FreeRTOS 20 Operating System
 * @brief FreeRTOS operating system port for Bolero
 * \defgroup FreeRTOSIntro FreeRTOSIntro
 * \ingroup 20_FreeRTOS
 * \defgroup LinkedList LinkedList
 * \ingroup 20_FreeRTOS
 * \defgroup QueueManagement QueueManagement
 * \ingroup 20_FreeRTOS
 * \defgroup SchedulerControl SchedulerControl
 * \ingroup 20_FreeRTOS
 * \defgroup Semaphores Semaphores
 * \ingroup 20_FreeRTOS
 * \defgroup Tasks Tasks
 * \ingroup 20_FreeRTOS
 * \defgroup TaskCtrl TaskCtrl
 * \ingroup 20_FreeRTOS
 * \defgroup TaskUtils TaskUtils
 * \ingroup 20_FreeRTOS
 * \defgroup RTOSConfig Free RTOS configuration
 * \ingroup 20_FreeRTOS
 * \defgroup FreeRTOSPort Free RTOS platform specific port
 * \ingroup 20_FreeRTOS
 * @{
 */

/*
    FreeRTOS V7.3.0 - Copyright (C) 2012 Real Time Engineers Ltd.

    FEATURES AND PORTS ARE ADDED TO FREERTOS ALL THE TIME.  PLEASE VISIT
    http://www.FreeRTOS.org TO ENSURE YOU ARE USING THE LATEST VERSION.

    ***************************************************************************
     *                                                                       *
     *    FreeRTOS tutorial books are available in pdf and paperback.        *
     *    Complete, revised, and edited pdf reference manuals are also       *
     *    available.                                                         *
     *                                                                       *
     *    Purchasing FreeRTOS documentation will not only help you, by       *
     *    ensuring you get running as quickly as possible and with an        *
     *    in-depth knowledge of how to use FreeRTOS, it will also help       *
     *    the FreeRTOS project to continue with its mission of providing     *
     *    professional grade, cross platform, de facto standard solutions    *
     *    for microcontrollers - completely free of charge!                  *
     *                                                                       *
     *    >>> See http://www.FreeRTOS.org/Documentation for details. <<<     *
     *                                                                       *
     *    Thank you for using FreeRTOS, and thank you for your support!      *
     *                                                                       *
    ***************************************************************************


    This file is part of the FreeRTOS distribution.

    FreeRTOS is free software; you can redistribute it and/or modify it under
    the terms of the GNU General Public License (version 2) as published by the
    Free Software Foundation AND MODIFIED BY the FreeRTOS exception.
    >>>NOTE<<< The modification to the GPL is included to allow you to
    distribute a combined work that includes FreeRTOS without being obliged to
    provide the source code for proprietary components outside of the FreeRTOS
    kernel.  FreeRTOS is distributed in the hope that it will be useful, but
    WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
    or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License for
    more details. You should have received a copy of the GNU General Public
    License and the FreeRTOS license exception along with FreeRTOS; if not it
    can be viewed here: http://www.freertos.org/a00114.html and also obtained
    by writing to Richard Barry, contact details for whom are available on the
    FreeRTOS WEB site.

    1 tab == 4 spaces!

    ***************************************************************************
     *                                                                       *
     *    Having a problem?  Start by reading the FAQ "My application does   *
     *    not run, what could be wrong?"                                     *
     *                                                                       *
     *    http://www.FreeRTOS.org/FAQHelp.html                               *
     *                                                                       *
    ***************************************************************************


    http://www.FreeRTOS.org - Documentation, training, latest versions, license
    and contact details.

    http://www.FreeRTOS.org/plus - A selection of FreeRTOS ecosystem products,
    including FreeRTOS+Trace - an indispensable productivity tool.

    Real Time Engineers ltd license FreeRTOS to High Integrity Systems, who sell
    the code with commercial support, indemnification, and middleware, under
    the OpenRTOS brand: http://www.OpenRTOS.com.  High Integrity Systems also
    provide a safety engineered and independently SIL3 certified version under
    the SafeRTOS brand: http://www.SafeRTOS.com.
*/

#ifndef FREERTOS_CONFIG_H
#define FREERTOS_CONFIG_H

/*-----------------------------------------------------------
 * Application specific definitions.
 *
 * These definitions should be adjusted for your particular hardware and
 * application requirements.
 *
 * THESE PARAMETERS ARE DESCRIBED WITHIN THE 'CONFIGURATION' SECTION OF THE
 * FreeRTOS API DOCUMENTATION AVAILABLE ON THE FreeRTOS.org WEB SITE. 
 *
 * See http://www.freertos.org/a00110.html.
 *----------------------------------------------------------*/
 
 //#include "10_HAL/Clock/SystemClockDrv_Config.h"
#include "DrvOs_Config.h"

#define configUSE_PREEMPTION            1
#define configUSE_IDLE_HOOK             1
#define configUSE_TICK_HOOK             0
//#define configMINIMAL_STACK_SIZE        ( ( unsigned portSHORT ) 100 )
#define configMINIMAL_STACK_SIZE        ( ( unsigned portSHORT ) (OS_STACK_SIZE_BYTES_MINIMUM/sizeof( StackType_t )) )
#define configCPU_CLOCK_HZ              ( ( unsigned portLONG ) CPU_CLOCK )	/* CPU clock setup */
#define configTICK_RATE_HZ              ( (TickType_t) RTOS_FREQUENCY )
#define configMAX_PRIORITIES            6
#define configTOTAL_HEAP_SIZE           ( (size_t) (OS_RTOS_HEAP_SIZE) )
#define configMAX_TASK_NAME_LEN         ( 13 )
#define configUSE_16_BIT_TICKS          0
#define configIDLE_SHOULD_YIELD         1
#define configUSE_MUTEXES               1
#define configUSE_TRACE_FACILITY        0
//#define configCHECK_FOR_STACK_OVERFLOW	0
//#define configCHECK_FOR_STACK_OVERFLOW	1//use simple stack overflow detection
#define configCHECK_FOR_STACK_OVERFLOW  2//use advanced stack overflow detection
#define configUSE_COUNTING_SEMAPHORES   0
#define configUSE_APPLICATION_TASK_TAG  0
#define configUSE_FPU                   0
#define configUSE_TIMERS                0
#define configUSE_RECURSIVE_MUTEXES     0

#if configUSE_TIMERS == 1
#error "DO NOT USE"
#define INCLUDE_xTimerPendFunctionCall	1
#define configTIMER_TASK_PRIORITY	tskIDLE_PRIORITY+5
#define configTIMER_QUEUE_LENGTH	10
#define configTIMER_TASK_STACK_DEPTH            configMINIMAL_STACK_SIZE*2
#endif

#define configENABLE_BACKWARD_COMPATIBILITY	0
#define configUSE_PORT_OPTIMISED_TASK_SELECTION	1

/* Co-routine definitions. */
#define configUSE_CO_ROUTINES           0
#define configMAX_CO_ROUTINE_PRIORITIES ( 4 )

/* Set the following definitions to 1 to include the API function, or zero
to exclude the API function. */
#define INCLUDE_vTaskPrioritySet             1
#define INCLUDE_uxTaskPriorityGet            1
#define INCLUDE_vTaskDelete                  0
#define INCLUDE_vTaskCleanUpResources        0
#define INCLUDE_vTaskSuspend                 1
#define INCLUDE_vResumeFromISR               1
#define INCLUDE_vTaskDelayUntil              1
#define INCLUDE_vTaskDelay                   0
#define INCLUDE_xTaskGetSchedulerState       0
#define INCLUDE_xTaskGetCurrentTaskHandle    0
#if OS_ENABLE_FREE_STACK_MEASUREMENT == 1
#define INCLUDE_uxTaskGetStackHighWaterMark  1
#define INCLUDE_xTaskGetIdleTaskHandle  1
#else
#define INCLUDE_uxTaskGetStackHighWaterMark  0
#endif
#define configUSE_MALLOC_FAILED_HOOK         1

//CPU usage calculation
#if ENABLE_CPU_USAGE_MEASUREMENT == 1
#include "DrvTimer.h"
	#define INCLUDE_xTaskGetIdleTaskHandle	1
	extern uint32_t OS_CpuUsageIdleTimerStart;
	extern uint32_t OS_CpuUsageIdleTime;
	extern uint8_t OS_CpuUsageIdleTaskRunning;
	#define traceTASK_SWITCHED_IN() if (pxCurrentTCB == xIdleTaskHandle) {\
			if (OS_CpuUsageIdleTaskRunning == 0) {\
				OS_CpuUsageIdleTimerStart = TIM_GETSYSTEMTIMER();\
				OS_CpuUsageIdleTaskRunning = 1;\
			}\
		} else {\
			if (OS_CpuUsageIdleTaskRunning == 1) {\
				OS_CpuUsageIdleTime+= TIM_GETELAPSEDTIME(OS_CpuUsageIdleTimerStart);\
				OS_CpuUsageIdleTaskRunning = 0;\
			}\
		}
#endif
	
#endif /* FREERTOS_CONFIG_H */
///@}
